@@ -22,9 +22,10 @@ import minishell_test.config as config
 import minishell_test.sandbox as sandbox
 from minishell_test.args import parse_args
 from minishell_test.suite.suite import Suite
-# from minishell_test.suites import *  # noqa: F403,F401
+from minishell_test.suites import *  # noqa: F403,F401
 
-from minishell_test.suites import cmd  # noqa: F403,F401
+# from minishell_test.suites import cmd  # noqa: F403,F401
+# from minishell_test.suites import flow  # noqa: F403,F401
 
 def main():
     args = parse_args()
