@@ -6,15 +6,15 @@
 #    By: charles <charles.cabergs@gmail.com>        +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 15:11:46 by charles           #+#    #+#              #
-#    Updated: 2021/02/04 16:14:54 by charles          ###   ########.fr        #
+#    Updated: 2021/02/05 15:11:14 by charles          ###   ########.fr        #
 #                                                                              #
 # ############################################################################ #
 
 import distutils
 
-import hooks
-import config
-from suite import suite
+import minishell_test.hooks as hooks
+import minishell_test.config as config
+from minishell_test.suite.decorator import suite
 
 
 @suite()
